@@ -25,7 +25,7 @@ alfa.tune <- function(x, B = 1, ncores = 1) {
     trans <- alfa(x, a)
     z <- trans$aff  ## the alpha-transformation
     sa <- trans$sa  ## part of the Jacobian determinant as well
-    -n/2 * log( abs( det( f * fastR::cova(z) ) ) ) + (a - 1) * ja - D * sa
+    -n/2 * log( abs( det( f * Rfast::cova(z) ) ) ) + (a - 1) * ja - D * sa
   }
 
   if (B == 1) {
@@ -33,7 +33,7 @@ alfa.tune <- function(x, B = 1, ncores = 1) {
     aff0 <- alfa(x, 0)
     z0 <- aff0$aff
     sa <- aff0$sa  ## part of the Jacobian determinant as well
-    lik0 <- con -  n/2 * log( abs( det( f * fastR::cova(z0) ) ) ) -
+    lik0 <- con -  n/2 * log( abs( det( f * Rfast::cova(z0) ) ) ) -
             ja - D * sa
     result <- c(ell$maximum, ell$objective + con, lik0)
     names(result) <- c("best alpha", "max log-lik", "log-lik at 0")
