@@ -8,7 +8,6 @@
 #### mtsagris@yahoo.gr
 ################################
 
-
 comp.knn <- function(xnew, x, ina, a = 1, k = 5, type = "S",
                      apostasi = "ESOV", mesos = TRUE) {
   ## xnew is the new dataset. It can be a single vector or a matrix
@@ -17,7 +16,7 @@ comp.knn <- function(xnew, x, ina, a = 1, k = 5, type = "S",
   ## a is the value of the power parameter
   ## k in the number of nearest neighbours
   ## apostasi is the type of metric used, "ESOV", "taxicab",
-  ## "Ait", "Hellinger", or "angualr"
+  ## "Ait", "Hellinger", "angular" or "CS"
   ## type is either S or NS. Should the standard k-NN be use or not
   ## if mesos is TRUE, then the arithmetic mean distance of the
   ## k nearest points will be used
@@ -37,11 +36,16 @@ comp.knn <- function(xnew, x, ina, a = 1, k = 5, type = "S",
   nu <- nrow(xnew)
   disa <- matrix(0, nu, n)
 
+  if (apostasi == "CS" & a == 0) {
+    apostasi = "Ait"
+  }
+
   if (apostasi == "ESOV") {
     xa <- x^a
     zx <- xa / rowSums( xa )  ## The power transformation is applied
     za <- xnew^a
     znew <- za / rowSums( za )  ## The power transformation is applied
+
     for (i in 1:nu) {
       zan <- znew[i, ]
       for (j in 1:n) {
@@ -56,6 +60,7 @@ comp.knn <- function(xnew, x, ina, a = 1, k = 5, type = "S",
     zx <- xa / rowSums( xa )  ## The power transformation is applied
     za <- xnew^a
     znew <- za / rowSums( za )  ## The power transformation is applied
+
     for (i in 1:nu) {
       b <- t(zx) - znew[i, ]
       disa[i, ] <- colSums( abs(b) )
@@ -67,17 +72,21 @@ comp.knn <- function(xnew, x, ina, a = 1, k = 5, type = "S",
     zx <- xa - rowMeans( xa )
     za <- log(xnew)
     znew <- za - rowMeans( za )
-    Ip <- diag(p)
+    tzx <- t(zx)
+
     for (i in 1:nu) {
-      disa[i, ] <- as.vector( sqrt( mahalanobis(zx, znew[i, ], Ip, inverted = TRUE) ) )
+      zz <- tzx - znew[i, ]
+      disa[i, ] <-  sqrt( colSums( zz^2 ) )
     }
 
   } else if ( apostasi == "Hellinger" ) {
     zx <- sqrt(x)
     znew <- sqrt(xnew)
-    Ip <- diag(p)
+    tzx <- t(zx)
+
     for (i in 1:nu) {
-      disa[i, ] <- as.vector( sqrt( mahalanobis(zx, znew[i, ], Ip, inverted = TRUE) ) )
+      zz <- tzx - znew[i, ]
+      disa[i, ] <-  sqrt( colSums( zz^2 ) )
     }
     disa <- disa / sqrt(2)
 
@@ -87,12 +96,27 @@ comp.knn <- function(xnew, x, ina, a = 1, k = 5, type = "S",
     disa <- tcrossprod( znew, zx )
     disa[disa >= 1] <- 1
     disa <- acos(disa)
+
+  }  else if ( apostasi == "CS" ) {
+     xa <- x^a
+     zx <- xa / rowSums( xa )  ## The power transformation is applied
+     za <- xnew^a
+     znew <- za / rowSums( za )  ##
+
+     for (i in 1:nu) {
+       for (j in 1:n) {
+         sa <- ( zx[j, ] - znew[i, ] )^2 / (zx[j, ] + znew[i, ])
+         disa[i, j] <- sum( sa[ abs(sa)<Inf ] )
+       }
+     }
+     disa <- 1 / abs(a) * sqrt(2 * p) * sqrt(disa)
   }
 
   ta <- matrix(nrow = nu, ncol = nc)
 
   if (type == "NS") {
     ## Non Standard algorithm
+
     for (m in 1:nc) {
       disa <- t( apply(disa, 1, sort) )
       if (mesos == TRUE) {
@@ -102,10 +126,12 @@ comp.knn <- function(xnew, x, ina, a = 1, k = 5, type = "S",
         ta[, m] <- k / rowSums( 1 / disa[, 1:k] )
       }
     }
+
     g <- apply(ta, 1, which.min)
 
   } else {   ## if type is "S"
     ## Standard algorithm
+
     g <- numeric(nu)
     for (l in 1:nu) {
       xa <- cbind(ina, disa[l, ])
