@@ -33,16 +33,6 @@ diri.est <- function(x, type = 'mle') {
    f
   }
 
-  ## entro is for the 'ent' type
-  entro <- function(param) {
-   f <- numeric( length(param) )
-   param <- exp(param)
-   for ( i in 1:length(f) ) {
-     f[i] <- ma[i] - digamma(param[i]) + digamma( sum(param) )
-   }
-   f
-  }
-
   if (type == 'mle') {
     runtime <- proc.time()
     options(warn = -1)
@@ -74,23 +64,6 @@ diri.est <- function(x, type = 'mle') {
     b = phi * a, runtime = runtime )
   }
 
-  if (type == 'ent') {
-    runtime <- proc.time()
-    ## this requires the BB package
-    ma <- colMeans(z)
-    da <- BB::BBsolve(colMeans(x) * 10, entro, control =
-    list(maxit = 20000, tol = 1e-10))
-    da <- BBsolve( da$par, entro, control = list(maxit = 20000, tol = 1e-10) )
-    da <- BBsolve( da$par, entro, control = list(maxit = 20000, tol = 1e-10) )
-    da <- BBsolve( da$par, entro, control = list(maxit = 20000, tol = 1e-10) )
-    param <- exp(da$par)
-    lik <- n * lgamma( sum(param) ) - n * sum( lgamma(param) ) +
-    sum( z %*% (param - 1) )
-
-    runtime <- proc.time() - runtime
-    result <- list( loglik = lik, param = param, runtime = runtime )
-  }
-
   result
 }
 
