@@ -62,7 +62,7 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
         qa <- nlm(jsreg, qa$estimate, z = zb)
         betaboot[i, ] <- qa$estimate
       }
-      s <- fastR::colVars(ww, std = TRUE)
+      s <- Rfast::colVars(ww, std = TRUE)
       seb <- matrix(s, byrow = TRUE, ncol = d)
       runtime <- proc.time() - runtime
 
@@ -82,7 +82,7 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
         betaboot[i, ] <- qa$estimate
       }
       stopCluster(cl)
-      s <- fastR::colVars(ww, std = TRUE)
+      s <- Rfast::colVars(ww, std = TRUE)
       seb <- matrix(s, byrow = TRUE, ncol = d)
       runtime <- proc.time() - runtime
     }
