@@ -63,7 +63,7 @@ kl.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
         qa <- nlm(klreg, qa$estimate, z = zb)
         betaboot[i, ] <- qa$estimate
       }
-      s <- fastR::colVars(ww, std = TRUE)
+      s <- Rfast::colVars(ww, std = TRUE)
       seb <- matrix(s, byrow = TRUE, ncol = d)
       runtime <- proc.time() - runtime
 
@@ -85,7 +85,7 @@ kl.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
        }
       stopCluster(cl)
 
-      s <- fastR::colVars(ww, std = TRUE)
+      s <- Rfast::colVars(ww, std = TRUE)
       seb <- matrix(s, byrow = TRUE, ncol = d)
       runtime <- proc.time() - runtime
     }
