@@ -25,8 +25,14 @@ mixnorm.contour <- function(x, mod) {
   mat <- matrix(nrow = n, ncol = n)
   ha <- t( helm(3) )
 
+  ldet <- numeric(g)
+  for (k in 1:g) {
+    ldet[k] <-  -0.5 * log( det(2 * pi * su[, , k]) )
+  }
+
   for ( i in 1:c(n/2) ) {
     for (j in 1:n) {
+
       if ( x2[j] < sqrt3 * x1[i] ) {
         ## This checks if the point will lie inside the triangle
         ## The next 4 lines calculate the composition
@@ -34,26 +40,29 @@ mixnorm.contour <- function(x, mod) {
         w2 <- x1[i] - x2[j] / sqrt3
         w1 <- 1 - w2 - w3
         w <- c(w1, w2, w3)
-        if (type == "alr") y <- log( w[-3]/w[3] )  ## alr transformation
-        if (type == "ilr") {  ## isometric log-ratio transformation
+        if ( type == "alr" )  y <- log( w[-3]/w[3] )  ## alr transformation
+        if ( type == "ilr" )  {  ## isometric log-ratio transformation
           y <- log(w) - mean(log(w))
           y <- as.vector( y %*% ha )
         }
+
         ta <- numeric(g)
         for (k in 1:g) {
-          ta[k] <-  -0.5 * log(det(2 * pi * su[, , k])) -
-          0.5 * mahalanobis(y, mu[k, ], su[, , k])
+          ta[k] <- ldet[k] - 0.5 * mahalanobis(y, mu[k, ], su[, , k])
         }
+
         can <- sum( prob * exp(ta) )
-        if (abs(can) < Inf) {
+        if ( abs(can) < Inf ) {
           mat[i, j] <- can
         } else  mat[i, j] <- NA
       }
+
     }
   }
 
   for ( i in c(n/2 + 1):n ) {
     for ( j in 1:n ) {
+
       ## This checks if the point will lie inside the triangle
       if ( x2[j] < sqrt3 - sqrt3 * x1[i] ) {
         ## The next 4 lines calculate the composition
@@ -61,21 +70,23 @@ mixnorm.contour <- function(x, mod) {
         w2 <- x1[i] - x2[j] / sqrt3
         w1 <- 1 - w2 - w3
         w <- c(w1, w2, w3)
-        if (type == "alr") y <- log( w[-3]/w[3] )  ## alr transformation
-        if (type == "ilr") {  ## isometric log-ratio transformation
+        if ( type == "alr" )  y <- log( w[-3]/w[3] )  ## alr transformation
+        if ( type == "ilr" )  {  ## isometric log-ratio transformation
           y <- log(w) - mean(log(w))
           y <- as.vector( y %*% ha )
         }
+
         ta <- numeric(g)
         for (k in 1:g) {
-          ta[k] <-  -0.5 * log(det(2 * pi * su[, , k])) -
-          0.5 * mahalanobis(y, mu[k, ], su[, , k])
+          ta[k] <-  ldet[k] - 0.5 * mahalanobis(y, mu[k, ], su[, , k])
         }
+
         can <- sum( prob * exp(ta) )
         if ( abs(can) < Inf ) {
           mat[i, j] <- can
         } else  mat[i, j] <- NA
       }
+
     }
   }
 
@@ -84,11 +95,12 @@ mixnorm.contour <- function(x, mod) {
   b2 <- c( sqrt3/2, 0, 0, sqrt3/2 )
   b <- cbind(b1, b2)
   points(b[ , 1], b[ , 2] , type = "l", xlab = " ", ylab = " ")
+
   nam <- colnames(x)
-  if ( is.null(nam) )  nam <- paste("X", 1:3, sep = "") 
+  if ( is.null(nam) )  nam <- paste("X", 1:3, sep = "")
   text( b[1, 1], b[1, 2] + 0.02, nam[3], cex = 1 )
   text( b[2:3, 1], b[2:3, 2] - 0.02, nam[1:2], cex = 1 )
-  proj <- matrix(c(0, 1, 1/2, 0, 0, sqrt3/2), ncol = 2)
+  proj <- matrix( c(0, 1, 1/2, 0, 0, sqrt3/2), ncol = 2 )
   xa <- x %*% proj
   points(xa[, 1], xa[, 2])
 
