@@ -40,7 +40,7 @@ rda <- function(xnew, x, ina, gam = 1, del = 0) {
 
   ni <- rep(ng - 1, each = D^2)
 
-  for (m in 1:nc)  sk[, , m] <- fastR::cova( x[ina == m, ] )
+  for (m in 1:nc)  sk[, , m] <- Rfast::cova( x[ina == m, ] )
   s <- ni * sk
   Sp <- apply(s, 1:2, sum) / (n - nc)  ## pooled covariance matrix
   sp <- diag( sum( diag( Sp ) ) / D, D ) ## spherical covariance matrix
@@ -49,7 +49,7 @@ rda <- function(xnew, x, ina, gam = 1, del = 0) {
   for (j in 1:nc) {
     Ska[, , j] <- del * sk[, , j] + (1 - del) * Sa
     ta[, j] <- ci[j] - 0.5 * log( det( Ska[, , j] ) ) -
-      0.5 * fastR::mahala( xnew, mesos[j, ], Ska[, , j] )
+      0.5 * Rfast::mahala( xnew, mesos[j, ], Ska[, , j] )
   }
 
   est <- max.col(ta)
