@@ -6,14 +6,17 @@
 
 rmvnorm <- function(n, mu, sigma) {
   ## n is the sample size,
-  ## mu is the mean vector and 
-  ## sigma is the covariance matrix 
+  ## mu is the mean vector and
+  ## sigma is the covariance matrix
   ## sigma does not have to be of full rank
+
   p <- length(mu)
   x <- matrix(rnorm(n * p), ncol = p)
-  eig <- eigen(sigma)  
+  eig <- eigen(sigma)
   lam <- eig$values
   vec <- eig$vectors
-  B <- ( vec %*% diag( sqrt(lam) ) ) %*% t(vec)
-  tcrossprod(x, B) + rep( mu, rep(n, p) )
-}
\ No newline at end of file
+  B <- vec %*% ( t(vec) * sqrt(lam) )
+  x <- tcrossprod(B, x) +  mu
+  t(x)
+
+}
