@@ -10,12 +10,14 @@ rmvt <- function(n, mu, sigma, v) {
   ## sigma is the covariance matrix
   ## sigma does not have to be of full rank
   ## v is the degrees of freedom
+
   p <- length(mu)
-  x <- matrix(rnorm(n * p), ncol = p)
-  w <- sqrt(v / rchisq(n, v))
+  x <- matrix( rnorm(n * p), ncol = p )
+  w <- sqrt( v / rchisq(n, v) )
   eig <- eigen(sigma)
   lam <- eig$values
   vec <- eig$vectors
-  B <- vec %*% diag( sqrt(lam) ) %*% t(vec)
+  B <- vec %*% ( t(vec) * sqrt(lam) )
   w * tcrossprod(x, B) + rep( mu, rep(n, p) )
-}
\ No newline at end of file
+
+}
